@@ -1,4 +1,5 @@
 """Defines the comic, volume, and page resources that make up a comic."""
+from functools import cached_property, lru_cache
 from pathlib import Path
 from typing import Iterator, Optional
 
@@ -60,6 +61,14 @@ class Volume:
             raise ScuzzieError("Attempt to get volume URL without a path.")
         return f"/volumes/{self.slug}.html"
 
+    @property
+    def first_page(self) -> Page | None:
+        """Returns the first page in this volume, or none if the volume has no pages."""
+        if not self.page_slugs:
+            return None
+
+        return self.pages[self.page_slugs[0]]
+
     @property
     def latest_page(self) -> Page | None:
         """Returns the latest page in this volume, or none if the volume has no pages."""
@@ -111,6 +120,14 @@ class Comic:
             f"placeholder={self.placeholder}, volume_slugs={self.volume_slugs})"
         )
 
+    @property
+    def first_volume(self) -> Volume | None:
+        """Returns the first volume in the comic, or none if the comic has no volumes."""
+        if not self.volume_slugs:
+            return None
+
+        return self.volumes[self.volume_slugs[0]]
+
     @property
     def latest_volume(self) -> Volume | None:
         """Returns the latest volume in the comic, or none if the comic has no volumes."""
@@ -119,6 +136,29 @@ class Comic:
 
         return self.volumes[self.volume_slugs[-1]]
 
+    @cached_property
+    def all_pages(self) -> list[Page]:
+        """Returns a list of all pages in the comic."""
+        return [page for volume in self.each_volume() for page in volume.each_page()]
+
+    @lru_cache
+    def page_after(self, page: Page) -> Page | None:
+        """Returns the page after the given page, or None if that is the last page."""
+        pages = self.all_pages
+        index = pages.index(page)
+        if index < len(pages) - 1:
+            return pages[index + 1]
+        return None
+
+    @lru_cache
+    def page_before(self, page: Page) -> Page | None:
+        """Returns the page before the given page, or None if that is the first page."""
+        pages = self.all_pages
+        index = pages.index(page)
+        if index > 0:
+            return pages[index - 1]
+        return None
+
     def each_volume(self) -> Iterator[Volume]:
         """Returns an iterator over all volumes in the comic."""
         for volume_slug in self.volume_slugs:
